bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 3. Aventiure
___________________________________________________
| ### DEN HERREN> mveten selten deheiniv hercen leit ### er horte sagn mære wi ein scoeniv meit ### wære in Bvrgonden ce wnsche wolgetan ### von der er sit vil vrevden vn– ovch arbeit gewan ### Div ir vnmazen scoene was vil witen chvnt ### vn– ir hoh gemvete zvo der selbn stvnt ### an der ivnchfrovwen so manech helt ervant ### ez ladete vil der geste in daz Gvnthers lant
###### 44 | ### Swaz man der werbenden nah ir minne sach ### Chrimhilt in ir sinne ir selber nie veriach ### daz si deheinen wolde ce eime trvote han ### er was ir noch vil vremde dem [293a] si wart sider vndertan
###### 45 | ### Do gedaht vof hohe minne daz Siglinde kint ### ez was ir aller werben wider in ein wint ### er mohte wol verdienen scoener frovwen lip ### sit wart div edele Chrimhilt des chvenen Sivrides wip
###### 46 | ### Im rieten sine mage vn– genvoge sine man ### sit er v^f stæte minne wolde tragen wan ### daz er dan eine wrbe div im mohte <zemen> ### do sprach der chvene Sivrit so wil ich Chiemhilden nemen
###### 47 | ### die scoenen ivnchfrovwen von Bvrgonden lant ### dvrch ir vnmazen scoene daz ist mir wol bechant ### nie keiser wart so riche der <wolde> haben wip ### im zæme wol ce minnen der richen chvneginne lip
| ### <Disiv> selbn mære gehorte Sigmvnt ### ez reiten sine livte da von wart im chvnt ### der wille sines chindes was im harte leit ### daz er werbn wolde di vil herlichen meit
###### 49 | ### Ez gevriesc ovch Siglint des edelen kvneges wip ### si hete groze sorge vm ir chindes lip ### wan si wol erchande Gvnthern vn– sine man ### den gewerp man dem degene sere <leiden> began
| ### Do sprach der chvene Sivrit vil lieber vater min ### an edeler frovwen minne wold ich immer sin ### ih enwrbe dar min herce vil groze liebe hat ### swaz iemn reden chvnde des ist decheinerslahte rat
###### 51 | ### Vnt wildv niht erwinden sprach der chvnech do ### so bin ich dins willen wærlichen vro ### vn– wil dirz helfen enden so ich aller beste chan ### doch hat der chvnech Gvnther vil manegen hohferten man
###### 52 | ### Ob ez ander niemn wære wan Hagene der degn ### der chan mit vbermvete der hohverte pflegn ### daz ich des sere fverhte ez mvg vns werden leit ### ob wir werbn welln di vil herlichen meit
| ### Waz mag vns daz gewerren sprach do Sivrit ### swaz ih friwentliche niht ab in erbit ### daz mach svs erwerbn mit ellen da min hant ### ich trwoe an in ertwingen <beide> livte vnd lant
###### 54 | ### Do sprach der fvrste Sigmvnt din rede div ist mir leit ### wan wrden disiv mære ce Rine geseit ### dvne dorftest nimmer geriten in daz lant ### Gvnther vn– Gernot di sint mir lange bechant
###### 55 | ### Mit gewalte niemn rewerben mach di magt ### so sprach der kvnec Sigmvnt daz ist mir wol gesagt ### wilt aber dv mit rechen riten in daz lant ### ob wir iht habn <vriwende> di werdent sciere besant [293b]
| ### Des enist mir niht cemvote sprach abr Sivrit ### daz mir svlen rechen ce Rîne volgen mit ### dvrh deheine hervart daz wære mir vil leit ### da mit ich solde ertwingen di vil wætlichn meit
###### 57 | ### Si mach wol svs erwerben da min eines hant ### ich wil selbe zwelfte in Gvnthers lant ### dar svlt ir mir helfen vater Sigmvnt ### do gap man sinen degenen ze chleidern gra vnd bvnt
| ### Do vernam ovch disiv mære sin mvoter Siglint ### si begvnde trvoren vm ir liebez chint ### daz vorhte si verliesen von Gvnthers man ### div edele chvneginne vil sere weinen began
###### 59 | ### Sivrit der herre gie da er si sach ### wider sine mvoter er gvetliche sprach ### frovwe ir svlt niht weinen dvrh den willen min ### ia wil ich an sorge vor allen wiganden sin
###### 60 | ### Vnd helfet mir der reise in Bvrgonden lant ### daz ich vn– mine rechen habn soelch gewant ### daz also stolce helde mit eren mvgen tragn ### des wil ich iv genade mit triwen wærlichen sagn
| ### <Sit> dv niht wil erwinden sprach frov Siglint ### so hilf ich dir der reise min einigez chint ### mit der besten wæte di riter ie getrvoch ### dir vn– dinen gesellen ir svlt ir fveren genvoch
###### 62 | ### Do neich der kvneginne Sivrit der ivnge man ### er sprach ih wil cer verte niemn mer han ### niwan zwelf rechen den sol man prveven wat ### ich wil daz sehen gerne wiez vm Chrimhilde stat
| ### <Do> sazen scoene frovwen naht vnd tach ### daz lvcel ir deheiniv rwoe gepflach ### vnce man geworhte di Sivrids wat ### er wolde siner reise habn deheiner slahte rat
###### 64 | ### Sin vater hiez im cieren sin riterlich gewant ### da mit er wolde rv^men daz Sigmvnds lant ### vn– ir vil liehten brvenne di wrden ovch bereit ### vn– ir vesten helme ir schilde scoen vn– breit
| ### Do nahet in ir reise cen Bvrgonden dan ### vm si begvnde sorgen wib vn– man ### ob si immer chomn solden heim wider in daz lant ### di helde in hiezen sovmen beide wafen vn– gewant
###### 66 | ### Ir ross div waren scoene ir gereite goldes rot ### lebt iemn vbermveter des enwas niht not ### denne wære Sivrit vn– di sine man ### vrlovbes er do gerte zvo den Bvrgonden dan
###### 67 | ### < · n> werten trvrechlichen der chvnech vn– sin wip ### er troste minnechlichen do ir beider lip ### er sprach ir svlt niht weinen dvrch den willen min ### immer ane sorge svlt ir mines libes sin
###### 68 | ### Ez was leit den rechen ez weinte ovch manech meit ### ich wæn in het ir herce rehte daz geseit ### daz in so vil der friwende da von gelæge tot ### von scvlden si do chlageten des [294a] gie in wærliche not
| ### An dem sibenden morgen ce Wormez vof den sant ### riten di vil chvenen allez ir gewant ### was von rotem golde ir gereite wolgetan ### ir ross in giengen ebene des chvenen Sivrids man
###### 70 | ### <Ir> schilde waren niwe lieht vnde breit ### vn– vil scoen ir helme da ce hove reit ### Sivrit der vil chvene in Gvnthers lant ### man gesach an helden nie so herlich gewant
###### 71 | ### Div ort ir swerten giengen nider vof den sporn ### ez fvorten scærpfe gern di riter voz erchorn ### Sivrit der fvort ir einen wol <zweier> spannen breit ### der zvo sinen ecken vil harte vreislichen sneit
###### 72 | ### Die goltvarwen zovme fvortens an der hant ### sidiniv fvrbvege svs chomens in daz lant ### daz volch si allenthalbn chapfen an began ### do liefen in engegene vil der Gvntheres man
| ### Di hohgemvoten rechen riter vnd chneht ### di giengen zvo den herrn daz was michl reht ### vn– enpfiengen dise geste in ir herrn lant ### vn– namen in di moere mit den schilden von der hant
###### 74 | ### Div ross si wolden dannen ziehen an gemach ### Sivrit der vil chvene wi snelle er do sprach ### lat vns sten di moere mir vn– minen man ### wir wellen sciere hinnen des ich vil gvoten willen han
###### 75 | ### Swem sin chvnt div mære der sol mich niht verdagn ### wa ich den kvnec vinde daz sol man mir sagn ### Gvnthern den vil richen voz Bvrgonden lant ### do sagt ez im ir einer dem ez rehte was bechant
| ### Welt ir den herrn vinden daz mach vil wol gescehn ### in ienem sale witen da han ich in gesehn ### bi den sinen helden da svlt ir hine gan ### da mvgt ir bi im vinden vil manegen herlichen man
###### 77 | ### Nv waren dem kvnge div mære geseit ### daz da chomen wæren riter vil gemeit ### di fvortn wizze brvenne vn– herlich gewant ### sinerchande niemn in der Bvrgonden lant
| ### Den kvnech des hete wnder von wannen choemn dar ### di herlichen rechen in wate lieht gevar ### vn– mit so gvoten scilden niwe vnd breit ### daz im daz sagte niemn daz was Gvnthere leit
###### 79 | ### Des antwrt dem kvnege von Mecen Oertwin ### rich vn– chvene moht er wol sin ### sit wir ir niht erchennen nv svlt ir heizen gan ### nach minem oeheim Hagenen den svlt ir si sehen lan
###### 80 | ### dem sint chvnt div riche vn– ovch div <vremden> lant ### sint im di herrn chvende daz tvot er [294b] vns bechant ### der chvnech bat in bringen vn– di sinen man ### man sach in herliche mit rechen hinz hove gan
###### 81 | ### Waz sin der kvnech wolde des vragte Hagene ### es sint in mime hvse vnchvnde degene ### di niemn hie bechennet habt ir si ie gesehn ### des svlt ir mir her Hagene der rehten warheite iehn
| ### Daz tvon ich sprach Hagne ceinem venster er da gie ### sin ovge er do wenchen zvo den gesten lie ### wol behagte im ir geverte vn– ovch ir gewant ### si waren im vil vremde in der Bvrgonden lant
###### 83 | ### Er sprach von swannen choemn di rechen an den Rin ### ez moehtn selbe fversten oder fverstn boten sin ### ir ross div wæren scoene ir <chleider> harte gvot ### von swannen daz si fveren si wæren hohgemvot
###### 84 | ### Also sprach do Hagne ich wil des wol veriehn ### swi ich Sivriden ni mer hab gesehn ### so wil ich wol gelovben swi ez dar vmbe stat ### daz ez si der reche der dort so herlichen gat
###### 85 | ### Er bringet niwe mære her in dize lant ### di chvenen Nibelvnge slvoch des heldes hant ### Schilbvnch vn– Nibelvngen div richen chvneges kint ### er frvmte starchiv wnder mit siner grozen chrefte sint
| ### <Da> der helt al eine an alle helfe reit ### er vant vor eime berge daz ist mir wol geseit ### bi Nibelvnges horde vil manegen chvenen man ### di waren im ê vremde vnz er ir chvnde da gewan
###### 87 | ### Hort der Nibelvnges der was gar getragn ### voz eime holem berge nv hoeret <wnder> sagn ### wi in wolden teilen der Nibelvnge man ### daz sach der degen Sivrit den helt ez wnderen began
###### 88 | ### Er chom zvo zin so nahen daz er di helde sach ### vn– ovch in di degene ir einer drvnder sprach ### hie chvmt der starche Sivrit der helt von Niderlant ### vil seltsæniv mære er an den Niblvngen vant
###### 89 | ### Den rechen wol enpfiengen Scilbvnch <vn–> Nibelvnch ### mit gemeinem rate di edeln fvrsten ivnch ### den scaz in baten teilen den wætlichen man ### vn– gerten des mit vlize der herre lobn inz began
| ### <Er> sach so vil gesteines so wir hoeren sagn ### hvndert chanz wægene ez moehten niht getragn ### noch me des roten goldes von Nibelvnge lant ### daz sold in allez teilen des chvenen Sivrides hant
###### 91 | ### Do gaben si im ce <miete> daz Nibelvnges swert ### si waren mit dem dienste vil vbele gewert [295a] ### den in da leisten solde Sivrit der helt gvot ### ern chvndez niht verenden si waren zornech gemvot
###### 92 | ### Si heten da ir frivnde zwelf chvene man ### daz starche risen waren waz chvndez si vervan ### di slvoch sit mit zorne div Sivrids hant ### vn– rechen siben hvndert twang er von Nibelvnge lant
###### 93 | ### mit dem gvotem swerte daz hiez Balmvnch ### dvrch di starchen vorhte vil manech reche ivnch ### di si cem swerte heten vn– an den chvenen man ### daz lant zvo den bvergen si im taten vndertan
| ### Dar <zvo> di richen chvnge di slvog er bede tot ### er chom von Albriche sit in groze not ### der wande sine herrn rechen da cehant ### vnz er di grozen sterche sit an Sivride vant
###### 95 | ### Done chvnd im niht gestriten daz starche getwerch ### alsam di lewen wilde si liefen an <den> perch ### da er di Tarenkappen sit Albriche an gewan ### do was des hordes herre Sivrit der vreisliche man
###### 96 | ### Di da torsten vehten di lagen alle erslagn ### den scaz den hiez er balde fveren vn– tragn ### da in da vor da namen di Nibelvnge man ### Albrich der vil starche do di kamern gewan
###### 97 | ### Er mvos im sweren eide er diente im so sin chneht ### aller hande dinge was er im gereht ### so sprach von Tronege hagene daz hat er getan ### also grozer chrefte <nie> mer reche gewan
###### 98 | ### Noch weiz ich an im mere daz mir ist bechant ### einen Lintrachen den slvoch des heldes hant ### er badet sich in dem blvote sin hvt wart hvrnin ### des snidet in chein wafen daz ist diche worden scin
###### 99 | ### Wir svln den herrn enpfahen deste baz ### daz wir iht verdienen des ivngen rechen haz ### sin lip der ist so chvene man sol in holden han ### er hat mit siner chrefte so menegiv wnder getan
| ### Do sprach der kvnech riche. dv maht wol habn war ### nv sich wi degenliche. er stet in strites var ### er vn– di sinen degene. der vil chvene man ### wir svlen im engegene. hin nider zvo dem rechen gan
###### 101 | ### Daz mvgt ir sprach do Hagene wol mit ern tvon ### er ist von edelem chvnne. eines richen kvnegs svn ### er stet inder gebære mich dvnchet wizze christ ### ez ensin niht chleiniv mære dar vmber her geriten ist
| ### <Do> sprach der kvnech des landes nv si vns willechomn ### er ist edel vnd chvene daz han ich wol vernomn ### des sol ovch er geniezen in Bvrgonden lant ### do gie der herre Gvnther da er <Sivriden> vant
###### 103 | ### Der wirt vn– sine rechen enpfiengen so den [295b] gast ### daz in an ir zvehten vil wenech iht gebrast ### des begvnd in nigen der wætliche man ### daz si in heten grvezen so rehte scone getan
| ### Mich wndert dirre mære sprach der kvnech cehant ### von wannen ir edel Sivrit sit chomn in dizze lant ### oder waz ir wellent werben ze Wormez an den Rin ### do sprach der gast cem kvnege daz sol ivch vnverdaget sin
###### 105 | ### Mir wart gesaget mære in mins vater lant ### daz hie bi iv wæren daz het ich gern erchant ### di chvensten rechen des han ich vil vernomn ### di ie chvnech gewnne dar vmbe bin ich her bechomn
###### 106 | ### Ovch hoere ich iv selben der degenheite iehn ### daz man kvnec deheinen chvener hab gesehn ### des redent vil di livte vber elliv disiv lant ### nv wil ich niht erwinden vnz ez mir <werde> bechant
###### 107 | ### Ich bin ovch ein reche vn– solde chrone tragn ### ich wil daz gerne fvegen daz si von mir sagn ### daz ich hab von rehte livte vn– lant ### dar vmbe sol min ere vn– ovch min hovbet wesen pfant
###### 108 | ### Nv ir sit so chvene als mir ist geseit ### sone rvoch ich ist daz iemn lieb od leit ### ich wil an iv ertwingen swaz ir mvget han ### lant vnde bvrge daz sol mir werden vndertan
| ### Den kvnec hete wnder vn– sine man alsam ### vm disiv mære di er hie vernam ### daz er des hete willen er næme im siniv lant ### daz horten sine degene do wart in zvernen bechant
###### 110 | ### Wie het ich daz verdienet sprach Gvnther der degn ### des min vater lange mit eren hat gepflegn ### daz wir daz solden vliesen von iemannes chraft ### wir liezen vbele schinen daz wir ovch pflegn riterschaft
| ### Ine wiles niht erwinden sprach aber <der> chvene man ### ez enmvge von dinen ellen din lant den fride han ### ich wiles alles walden vnd ovch div erbe min ### erwirbest dvz mit sterche div svelen dir vndertænech sin
###### 112 | ### Din erbe vn– ovch daz mine svlen geliche lign ### sweder vnser einer am andern mach gesign ### dem sol ez allez dienen di livte vnd ovch div lant ### daz wider redete Hagene vn– Gernot ce hant
| ### <Wir> han des niht gedingen sprach do Gernot ### daz wir iht lande ertwingen daz iemn drvmbe tot ### gelige vor heldes handen wir habn richiv lant ### div dienent vns von rehte ze niemn sint si baz bewant
###### 114 | ### Mit grimmigem mvote da stvonden friwende sin ### do was ovch dar vnder von Mecen Oertwin ### der sprach disiv svone div ist mir harte leit [296a] ### iv hat der starche Sivrit vnverdient widerseit
###### 115 | ### Ob ir vn– iwer brvoder hetet niht di wer ### vnd ob er danne fvorte ein gancez kvneges her ### ih trvote wol erstriten daz der chvene man ### diz starchez vbermveten von waren schvlden mvese lan
| ### <Daz> zvrnde harte sere der helt von Niderlant ### er sprach sich sol vermezzen niht wider mich din hant ### ich bin ein kvnec riche so bistv kvneges man ### iane dorften mich din zwelve mit strite nimmer bestan
| ### <Nach> swerten rief do sere von Mecen Oertwin ### er mohte Hagenen swester svn von Tronege vil wol sin ### daz der so lange dagete daz was dem kvnege leit ### do vnderstvondez Gernot der riter chven vnt gemeit
###### 118 | ### Er sprach ce Oertwine lat iwer zvrnen stan ### vns enhat der herre Sivrit solhes niht getan ### wir enmvgenz noch wol sceiden mit zvehten deist min rat ### vn– habn in ce friwende daz vns noch loblicher stat
| ### <Do> sprach der starche Hagne vns mach wol wesen leit ### allen dinen degenen daz er ie gereit ### dvrch striten her ce Rine er soltez habn lan ### im heten mine herren soelher leide niht getan
###### 120 | ### < · es> antwrte Sivrit der chreftige man ### mvet ivch daz her Hagene daz ich gesprochen han ### so sol ich lazen chiesen daz die hende min ### wellent vil gewaltech hie cen bvrgonden sin
###### 121 | ### Daz sol ich eine wenden sprach aber Gernot ### allen sinen degenen reden er verbot ### iht mit vbermvete des im wære leit ### do gedahte ovch Sivrit an di herlichen meit
| ### <Vie> zæme vns mit iv striten sprach aber Gernot ### swaz helde nv dar vnder mvese ligen tot ### wir hetens lvcel ere vn– ir vil chleinen frvm ### des antwrte im do Sivrit des kvnech Sigmvndes svn
###### 123 | ### War vmbe bitet Hagne vn– ovch Oertwin ### daz er niht gaht striten mit den friwenden sin ### der er hie so manegn cen Bvrgonden hat ### si mvosen rede vermiden daz was Gernotes rat
| ### <Er> svlt vns wesen willechomn so sprach daz voten kint ### mit iwern gesellen di mit iv chomn sint ### wir svlen iv gerne dienen ich vn– di mage min ### do hiez man den gesten scenchen den Gvnthers win
###### 125 | ### Do sprach der wirt des landes allez daz wir han ### gervochet irs nach eren daz si iv vndertan ### vn– si mit iv geteilet lib vn– gvot ### do wart der herre Sivrit ein lvcel sanfter gemvot
| ### Do hiez man in gehalten allez ir gewant ### man svochte herberge di besten di man vant ### Sivrids chnehten man scvof in gvot gemach [296b] ### den gast man sit vil gerne da cen Bvrgonden sach
###### 127 | ### Man bot im michel ere. dar nach ce manegn tagn ### tvsent stvnden mere. dann ich iv chan gesagn ### daz het versolt sin ellen. ir svlt gelovben daz ### in sach vil lvcel iemen. der im wære gehaz
| ### <Sich> vlizen chvrzwile di kvnege vn– ovch ir man ### so was er ie der beste swes man da began ### des enchvnd im gevolgen <niemen> so michel was sin chraft ### so si den stein wrfn oder schvzen den scaft
###### 129 | ### Swa so bi den frovwen dvrch ir hofscheit ### chvrcewile pflagen di riter vil gemeit ### da sah man ie vil gerne den helt von Niderlant ### er het vf hohe minne sine sinne gewant
###### 130 | ### Swes man ie begvnde des was sin lip bereit ### er trvog insime sinne ein minnechliche meit ### vn– ovch in ein div frovwe di er noh nie gesach ### div im in heinliche vil diche gvetlichen sprach
| ### Swenne v^f dem hove wolden spilen da div kint ### riter vnd chnehte daz sach vil diche sint ### Chrimhilt dvrch div venster div kvneginne her ### deheiner chvrzwile bedorftes in den citen mer
###### 132 | ### Wesser daz in sæhe di er in hercen trvoch ### da het er chvrze wile immer von genvoch ### sæhen sie siniv ovgen ich wil wol wizen daz ### daz im in dirre werlde chvnde nimmer werden baz
###### 133 | ### Swenner bi den helden v^f dem hove stvont ### also noch di livte dvrch chvrce wile tvont ### so stvont so minnechliche daz Siglinde kint ### daz in dvrch hercen liebe trvote manech frovwe sint
| ### <Er> gedaht ovch manege cite wi sol daz gescehen ### daz ich di maget edele mit ovgen mvge sehen ### di ich von hercen minne vn– lange han getan ### div ist mir noch vil vremde des mvoz ich trvorich stan
###### 135 | ### So ie di kvnege riche riten in ir lant ### so mvosen ovch di rechen mit in al ce hant ### da mite mvos ovch Sivrit daz was der <frovn> leit ### er leit ovch von ir minne diche michel arbeit
###### 136 | ### Svss wont er bi den herrn daz ist al war ### in Gvnthers lande vollechlich ein iar ### daz er di minnechlichen di cite <nien> gesach ### da von im sit vil liebe vn– ovch vil leide gescach

<<< Übersicht <<< vorige Seite nächste Seite >>>